==> TuxGuitar-0.2.tar.gz: TuxGuitar-0.2/src/org/herac/tuxguitar/gui/items/tool/InsertToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.insert.InsertChordAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class InsertToolItems implements ItemContainer {
    public static final String NAME = "INSERT_ITEMS";
    
    private TablatureEditor tablatureEditor;
    private ToolBar toolBar;   
    
    public InsertToolItems(TablatureEditor tablatureEditor,ToolBar toolBar){
        this.tablatureEditor = tablatureEditor;
        this.toolBar = toolBar;
    }
   
    public void showItems(){                       
        ToolItem insertChord = new ToolItem(toolBar, SWT.PUSH);
        insertChord.setImage(new Image(toolBar.getDisplay(), TuxGuitar.getResourcePath(this, "chord.png")));
        insertChord.setToolTipText("Chord");
        insertChord.addSelectionListener(TuxGuitar.instance().getAction(InsertChordAction.NAME));                         
    }

    
    public void update(){
        
    }
}

==> TuxGuitar-0.3.tar.gz: TuxGuitar-0.3/src/org/herac/tuxguitar/gui/items/tool/InsertToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.insert.InsertChordAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class InsertToolItems implements ItemContainer {
    public static final String NAME = "INSERT_ITEMS";
    
    private TablatureEditor tablatureEditor;
    private ToolBar toolBar;   
    private ToolItem insertChord;
    
    public InsertToolItems(TablatureEditor tablatureEditor,ToolBar toolBar){
        this.tablatureEditor = tablatureEditor;
        this.toolBar = toolBar;
    }
   
    public void showItems(){                       
        insertChord = new ToolItem(toolBar, SWT.PUSH);
        insertChord.setImage(new Image(toolBar.getDisplay(), TuxGuitar.getResourcePath(this, "chord.png")));
        insertChord.addSelectionListener(TuxGuitar.instance().getAction(InsertChordAction.NAME));                         
    
        this.loadProperties();
    }

    
    public void update(){
        
    }
    
    
    public void loadProperties(){
        this.insertChord.setToolTipText(TuxGuitar.getProperty("insert.chord"));  
    }    
}
